from time import sleep
import boto3
# this is running in a localstack env so ignore all the SSL warnings
#import botocore.vendored.requests.packages.urllib3 as boto_urllib3
import os

#boto_urllib3.disable_warnings(boto_urllib3.exceptions.InsecureRequestWarning)
import urllib3
urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)

# This script sets up fake AWS environment for Dockerized CbD instances
LOCALSTACK_HOST = os.environ.get('LOCALSTACK_HOST', 'https://localhost')
RESOURCE_PREFIX = os.environ.get('RESOURCE_PREFIX', 'local')

script_path = os.path.dirname(os.path.abspath(__file__))

# Create all dependant Kinesis streams
print("Creating Kinesis streams")
kinesis = boto3.client(
    'kinesis',
    region_name="us-east-1",
    endpoint_url="{0}:4568".format(LOCALSTACK_HOST),
    aws_access_key_id="",
    aws_secret_access_key="",
    verify=False
)

# Check Kinesis Endpoint Availability
print("Checking Kinesis Endpoint Availability")
retry = True
while(retry):
    try:
        kinesis.list_streams()
        retry = False
    except Exception as e:
        print("Waiting for Endpoint to be ready...")
        sleep(5)
        pass

print("Kinesis stream for LQ results")
try:
    kinesis.create_stream(
        StreamName="{0}__livequery_results".format(RESOURCE_PREFIX),
        ShardCount=3
    )
except kinesis.exceptions.ResourceInUseException:
    pass

print("Kinesis stream for Vulnerability results")
try:
    kinesis.create_stream(
        StreamName="psc-cwp-{0}-vulnerability-results".format(RESOURCE_PREFIX),
        ShardCount=3
    )
except kinesis.exceptions.ResourceInUseException:
    pass

print("Kinesis stream for Vulnerability reassess results")
try:
    kinesis.create_stream(
        StreamName="psc-cwp-{0}-vulnerability-reassess-results".format(RESOURCE_PREFIX),
        ShardCount=3
    )
except kinesis.exceptions.ResourceInUseException:
    pass

print("Kinesis stream for Compliance Scan results")
try:
    kinesis.create_stream(
        StreamName="psc-cwp-{0}-compliance-results".format(RESOURCE_PREFIX),
        ShardCount=3
    )
except kinesis.exceptions.ResourceInUseException:
    pass


print("creating S3 bucket")
s3 = boto3.client(
    's3',
    region_name="us-east-1",
    endpoint_url="{0}:4572".format(LOCALSTACK_HOST),
    aws_access_key_id="",
    aws_secret_access_key="",
    verify=False
)
bucket = "psc-livequery-{0}-tau-queries".format(RESOURCE_PREFIX)
s3.create_bucket(Bucket=bucket)
s3.upload_file(
    os.path.join(script_path, 'tauQueries.json'),
    bucket,
    'latest.json'
)
s3.upload_file(
    os.path.join(script_path, 'v1.json'),
    bucket,
    'v1.json'
)
s3.create_bucket(Bucket="psc-livequery-{0}-jobs".format(RESOURCE_PREFIX))
